RenderConfig

Struct RenderConfig 

pub struct RenderConfig {
    pub canvas_width: u32,
    pub canvas_height: u32,
    pub icon_size: u32,
    pub supersample_factor: u32,
    pub icon_color: Color,
    pub background_color: Color,
    pub horizontal_anchor: HorizontalAnchor,
    pub vertical_anchor: VerticalAnchor,
    pub offset_x: i32,
    pub offset_y: i32,
    pub rotate: f64,
}
Configuration for rendering an icon.

Fields

canvas_width: u32

Canvas width in pixels

canvas_height: u32

Canvas height in pixels

icon_size: u32

Icon size in pixels (height of the icon)

supersample_factor: u32

Supersampling factor for antialiasing (default: 2)

icon_color: Color

Icon foreground color

background_color: Color

Background color (use transparent for no background)

horizontal_anchor: HorizontalAnchor

Horizontal anchor position

vertical_anchor: VerticalAnchor

Vertical anchor position

offset_x: i32

Horizontal pixel offset from anchor

offset_y: i32

Vertical pixel offset from anchor

rotate: f64

Rotation angle in degrees (positive = clockwise, negative = counter-clockwise)

Implementations

Source

impl RenderConfig

pub fn new() -> Self

Create a new config with default values.

pub fn canvas_size(self, width: u32, height: u32) -> Self

Set canvas dimensions.

pub fn icon_size(self, size: u32) -> Self

Set icon size.

pub fn supersample(self, factor: u32) -> Self

Set supersampling factor.

pub fn icon_color(self, color: Color) -> Self

Set icon color.

pub fn background_color(self, color: Color) -> Self

Set background color.

pub fn anchor( self, horizontal: HorizontalAnchor, vertical: VerticalAnchor, ) -> Self

Set anchor positions.

pub fn offset(self, x: i32, y: i32) -> Self

Set pixel offset from anchor.

pub fn rotate(self, degrees: f64) -> Self

Set rotation angle in degrees.

Positive values rotate clockwise, negative values rotate counter-clockwise. The rotation is applied around the center of the icon before compositing.

Arguments
  • degrees - Rotation angle in degrees
Examples
use icon_to_image::RenderConfig;

// Rotate 45 degrees clockwise
let config = RenderConfig::new().rotate(45.0);

// Rotate 90 degrees counter-clockwise
let config = RenderConfig::new().rotate(-90.0);
pub fn sanitize_icon_size(self) -> Self

Apply sanity check to icon_size, clamping to 95% of smaller canvas dimension if it exceeds either canvas dimension.

This prevents icons from being larger than the canvas, which would cause rendering issues.